﻿//////////////////////////////////////////////////////////////////////////
//定时任务
//策略描述：
//	典型如选股交易。比如，策略每日收盘前10分钟执行：选股->决策逻辑->交易->退出。可能无需订阅实时数据。

using GMSDK;

namespace TimedTask
{
    public class MyStrategy : Strategy
    {
        public MyStrategy(string token, string strategyId, StrategyMode mode) : base(token, strategyId, mode) { }

        //重写OnInit事件，进行策略开发
        public override void OnInit()
        {
            System.Console.WriteLine("OnInit");

            //设置定时任务
            Schedule("1d", "13:24:00");
            return;
        }

        //定时任务触发事件
        public override void OnSchedule(string data_rule, string timeRule)
        {
            //购买200股浦发银行股票
            GMData<Order> o = OrderValue("SHSE.600000", 200, OrderSide.OrderSide_Buy, OrderType.OrderType_Market, PositionEffect.PositionEffect_Open, 0);
            if (o.status == 0)   //该判断仅表示函数调用无异常
            {
                //
            }
        }

        //回测完成后收到绩效报告
        public override void OnBacktestFinished(Indicator indicator)
        {
            System.Console.WriteLine("OnIndicator：");
            System.Console.WriteLine("{0,-50}{1}", "账号ID：", indicator.accountId);
            System.Console.WriteLine("{0,-50}{1}", "累计收益率：", indicator.pnlRatio);
            System.Console.WriteLine("{0,-50}{1}", "年化收益率：", indicator.pnlRatioAnnual);
            System.Console.WriteLine("{0,-50}{1}", "夏普比率：", indicator.sharpRatio);
            System.Console.WriteLine("{0,-50}{1}", "最大回撤：", indicator.maxDrawdown);
            System.Console.WriteLine("{0,-50}{1}", "风险比率：", indicator.riskRatio);
            System.Console.WriteLine("{0,-50}{1}", "开仓次数：", indicator.openCount);
            System.Console.WriteLine("{0,-50}{1}", "平仓次数：", indicator.closeCount);
            System.Console.WriteLine("{0,-50}{1}", "盈利次数：", indicator.winCount);
            System.Console.WriteLine("{0,-50}{1}", "亏损次数：", indicator.loseCount);
            System.Console.WriteLine("{0,-50}{1}", "胜率：", indicator.winRatio);
            System.Console.WriteLine("{0,-50}{1}", "指标创建时间：", indicator.createdAt);
            System.Console.WriteLine("{0,-50}{1}", "指标变更时间：", indicator.updatedAt);
        }
    }
    class Program
    {
        static void Main(string[] args)
        {
            MyStrategy s = new MyStrategy("{{token}}","{{strategyId}}", StrategyMode.MODE_BACKTEST);
            s.SetBacktestConfig("2016-07-11 17:20:00", "2017-07-11 17:30:00");
            s.Run();
            System.Console.WriteLine("回测完成！");
            System.Console.Read();
        }
    }
}